@@ -1,8 +1,9 @@
-# @(#)Ident: ;
+# @(#)Ident: Root.pm 2013-09-29 00:51 pjf ;
 
 package CatalystX::Usul::Controller::Root;
 
-use version; our $VERSION = qv( sprintf '0.9.%d', q$Rev: 0 $ =~ /\d+/gmx );
+use strict;
+use version; our $VERSION = qv( sprintf '0.13.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use CatalystX::Usul::Constants;
 use CatalystX::Usul::Functions qw( env_prefix is_member throw );
@@ -224,7 +225,7 @@ CatalystX::Usul::Controller::Root - Root Controller for the application
 
 =head1 Version
 
-Describes v0.9.$Rev: 0 $
+Describes v0.13.$Rev: 1 $
 
 =head1 Synopsis
 
