@@ -1,8 +1,9 @@
-# @(#)Ident: ;
+# @(#)Ident: Config.pm 2013-09-29 00:53 pjf ;
 
 package CatalystX::Usul::Model::Config;
 
-use version; our $VERSION = qv( sprintf '0.9.%d', q$Rev: 0 $ =~ /\d+/gmx );
+use strict;
+use version; our $VERSION = qv( sprintf '0.13.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use Class::Usul::File;
 use CatalystX::Usul::Constants;
@@ -410,7 +411,7 @@ CatalystX::Usul::Model::Config - Read and write configuration files
 
 =head1 Version
 
-Describes v0.9.$Rev: 0 $
+Describes v0.13.$Rev: 1 $
 
 =head1 Synopsis
 
